@@ -1,7 +1,7 @@
 /*
-   $Id: dbdimp.c 379 2007-05-20 14:49:38Z edpratomo $
+   $Id: dbdimp.c 395 2008-01-08 05:33:11Z edpratomo $
 
-   Copyright (c) 1999-2006  Edwin Pratomo
+   Copyright (c) 1999-2008  Edwin Pratomo
    Portions Copyright (c) 2001-2005  Daniel Ritz
 
    You may distribute under the terms of either the GNU General Public
@@ -224,12 +224,11 @@ static int ib2sql_type(int ibtype)
     return -9000 - ibtype;
 }
 
-
+#if 0
 /* from DBI (ANSI/ISO/ODBC) types to InterBase types */
 static int ib_sql_type(imp_sth_t *imp_sth, char *name, int sql_type)
 {
     /* XXX should detect DBI reserved standard type range here */
-/*
     switch (sql_type) {
     case DBI_SQL_NUMERIC:
     case DBI_SQL_DECIMAL:
@@ -254,9 +253,8 @@ static int ib_sql_type(imp_sth_t *imp_sth, char *name, int sql_type)
         warn("SQL type %d for '%s' is not fully supported, bound as SQL_VARCHAR instead");
     return ib_sql_type(imp_sth, name, DBI_SQL_VARCHAR);
     }
-*/
 }
-
+#endif
 
 int dbd_db_login6(SV *dbh, imp_dbh_t *imp_dbh, char *dbname, char *uid,
                   char *pwd, SV *attr)
@@ -2788,13 +2786,14 @@ int ib_commit_transaction(SV *h, imp_dbh_t *imp_dbh)
 {
     ISC_STATUS status[ISC_STATUS_LENGTH];
 
-    DBI_TRACE_imp_xxh(imp_dbh, 2, (DBIc_LOGPIO(imp_dbh), "ib_commit_transaction\n"));
-    DBI_TRACE_imp_xxh(imp_dbh, 4, (DBIc_LOGPIO(imp_dbh), "ib_commit_transaction: DBIcf_AutoCommit = %d, imp_dbh->sth_ddl = %d\n",
-                  DBIc_has(imp_dbh, DBIcf_AutoCommit), imp_dbh->sth_ddl));
+    DBI_TRACE_imp_xxh(imp_dbh, 4, (DBIc_LOGPIO(imp_dbh), 
+        "ib_commit_transaction: DBIcf_AutoCommit = %d, imp_dbh->sth_ddl = %d\n",
+        DBIc_has(imp_dbh, DBIcf_AutoCommit), imp_dbh->sth_ddl));
 
     if (!imp_dbh->tr)
     {
-        DBI_TRACE_imp_xxh(imp_dbh, 3, (DBIc_LOGPIO(imp_dbh), "ib_commit_transaction: transaction already NULL.\n"));
+        DBI_TRACE_imp_xxh(imp_dbh, 3, (DBIc_LOGPIO(imp_dbh), 
+            "ib_commit_transaction: transaction already NULL.\n"));
         /* In case we switched to use different TPB before we actually use */
         /* This transaction handle                                         */
         imp_dbh->sth_ddl = 0;
@@ -2816,7 +2815,9 @@ int ib_commit_transaction(SV *h, imp_dbh_t *imp_dbh)
     else
     {
         /* close all open statement handles */
-        if ((imp_dbh->sth_ddl > 0) || !(DBIc_has(imp_dbh, DBIcf_AutoCommit)))
+        /* if ((imp_dbh->sth_ddl > 0) || !(DBIc_has(imp_dbh, DBIcf_AutoCommit))) */
+        /* remark: only necessary when we have DDL statement(s) */
+        if (imp_dbh->sth_ddl > 0)
         {
             while (imp_dbh->first_sth != NULL)
             {
